# -*- coding: utf-8 -*-
from django.forms import TextInput

class MaskedWidget(TextInput):
    """
    jQuery MaskedInput Widget.
    """
    class Media:
        js = (
            'masked_forms/js/jquery.maskedinput.js',
            'masked_forms/js/masked_forms.js',
        )
    def __init__(self, mask_format=None, *args, **kwargs):
        super(MaskedWidget, self).__init__(*args, **kwargs)
        if not mask_format:
            raise TypeError("mask_format paramater can't by empty" )
        self.mask_format = mask_format
        self.attrs['class'] = ' masked'
        self.attrs['mask']  = self.mask_format 


from setuptools import setup
 
version = '0.0.2'
 
LONG_DESCRIPTION = """
=====================================
django-masked-forms (Django masked_forms)
=====================================

"""
 
setup(
    name='django-masked-forms',
    version=version,
    description="django masked forms",
    long_description=LONG_DESCRIPTION,
    classifiers=[
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Framework :: Django",
        "Environment :: Web Environment",
    ],
    keywords='jQuery,django,mask,form fields',
    author='Mateus Lorandi dos Santos',
    author_email='mcomogo@gmail.com',
    license='MIT',
    packages=['masked_forms'],
    url='https://github.com/comogo/django-masked-forms',
    include_package_data=True,
    exclude_package_data={'': ['example']},
    zip_safe=False,
)
